@@ -19,7 +19,7 @@ from simpledate.utils import DebugLog, MRUSortedIterable, OrderedSet
 
 # Build the various formats used by SimpleDateParser.
 
-RFC_2822 = ('{%a!,! ?}?%d !%b !%Y !%H:!%M{:!%S}?{ !%Z!| !?%z}?',)
+RFC_2822 = EMAIL = ('{%a!,! ?}?%d !%b !%Y !%H:!%M{:!%S}?{ !%Z!| !?%z}?',)
 ISO_8601 = ('%Y{-!%m{-!%d{{ !|T}%H:!%M{:!%S{.%f}?}?}?}?}?{ !%Z!| !?%z}?',)
 MDY = ('{%m/!%d/!}?%Y{ !%H:!%M{:!%S{.%f}?}?}?{ !%Z!| !?%z}?',)
 DMY = ('{%d/!%m/!}?%Y{ !%H:!%M{:!%S{.%f}?}?}?{ !%Z!| !?%z}?',)
@@ -93,7 +93,6 @@ def tzinfo_tzname(tzinfo, datetime, is_dst):
         return name
 
 
-
 def tzinfo_utcoffset(tzinfo, datetime):
     '''
     Get the UTC offset for the timezone at this time, avoiding an error when
